#if defined (HAVE_CONFIG_H)
#  include "config.h"
#endif
/****************************************************************************
** Meta object code from reading C++ file 'moc-files-dock-widget.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.10.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "libgui/src/moc-files-dock-widget.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'moc-files-dock-widget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.10.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6octave19file_system_browserE_t {};
} // unnamed namespace

template <> constexpr inline auto octave::file_system_browser::qt_create_metaobjectdata<qt_meta_tag_ZN6octave19file_system_browserE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "octave::file_system_browser",
        "open_file",
        "",
        "fileName",
        "displayed_directory_changed",
        "dir",
        "load_file_signal",
        "open_any_signal",
        "run_file_signal",
        "QFileInfo",
        "info",
        "ops",
        "find_files_signal",
        "startdir",
        "file_remove_signal",
        "old_name",
        "new_name",
        "file_renamed_signal",
        "modify_path_signal",
        "dir_list",
        "rm",
        "subdirs",
        "item_double_clicked",
        "QModelIndex",
        "index",
        "change_directory_up",
        "do_sync_octave_directory",
        "do_sync_browser_directory",
        "set_current_directory",
        "accept_directory_line_edit",
        "update_octave_directory",
        "notice_settings",
        "save_settings",
        "restore_header_state",
        "headercontextmenu_requested",
        "QPoint",
        "pos",
        "toggle_header",
        "col",
        "contextmenu_requested",
        "contextmenu_open",
        "contextmenu_open_in_editor",
        "contextmenu_open_in_app",
        "contextmenu_copy_selection",
        "contextmenu_run",
        "contextmenu_load",
        "contextmenu_rename",
        "contextmenu_delete",
        "contextmenu_newfile",
        "contextmenu_newdir",
        "contextmenu_setcurrentdir",
        "contextmenu_add_to_path",
        "contextmenu_add_to_path_subdirs",
        "contextmenu_rm_from_path",
        "contextmenu_rm_from_path_subdirs",
        "contextmenu_findfiles",
        "popdownmenu_newfile",
        "popdownmenu_newdir",
        "popdownmenu_search_dir",
        "popdownmenu_findfiles",
        "popdownmenu_home",
        "copyClipboard",
        "pasteClipboard",
        "selectAll"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'open_file'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'displayed_directory_changed'
        QtMocHelpers::SignalData<void(const QString &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Signal 'load_file_signal'
        QtMocHelpers::SignalData<void(const QString &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'open_any_signal'
        QtMocHelpers::SignalData<void(const QString &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'run_file_signal'
        QtMocHelpers::SignalData<void(const QFileInfo &, int)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 }, { QMetaType::Int, 11 },
        }}),
        // Signal 'find_files_signal'
        QtMocHelpers::SignalData<void(const QString &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 13 },
        }}),
        // Signal 'file_remove_signal'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 15 }, { QMetaType::QString, 16 },
        }}),
        // Signal 'file_renamed_signal'
        QtMocHelpers::SignalData<void(bool)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'modify_path_signal'
        QtMocHelpers::SignalData<void(const QStringList &, bool, bool)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 19 }, { QMetaType::Bool, 20 }, { QMetaType::Bool, 21 },
        }}),
        // Slot 'item_double_clicked'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 23, 24 },
        }}),
        // Slot 'change_directory_up'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'do_sync_octave_directory'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'do_sync_browser_directory'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'set_current_directory'
        QtMocHelpers::SlotData<void(const QString &)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Slot 'accept_directory_line_edit'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'update_octave_directory'
        QtMocHelpers::SlotData<void(const QString &)>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Slot 'notice_settings'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'save_settings'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'restore_header_state'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'headercontextmenu_requested'
        QtMocHelpers::SlotData<void(const QPoint &)>(34, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 35, 36 },
        }}),
        // Slot 'toggle_header'
        QtMocHelpers::SlotData<void(int)>(37, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 38 },
        }}),
        // Slot 'contextmenu_requested'
        QtMocHelpers::SlotData<void(const QPoint &)>(39, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 35, 36 },
        }}),
        // Slot 'contextmenu_open'
        QtMocHelpers::SlotData<void(bool)>(40, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'contextmenu_open_in_editor'
        QtMocHelpers::SlotData<void(bool)>(41, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'contextmenu_open_in_app'
        QtMocHelpers::SlotData<void(bool)>(42, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'contextmenu_copy_selection'
        QtMocHelpers::SlotData<void(bool)>(43, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'contextmenu_run'
        QtMocHelpers::SlotData<void(bool)>(44, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'contextmenu_load'
        QtMocHelpers::SlotData<void(bool)>(45, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'contextmenu_rename'
        QtMocHelpers::SlotData<void(bool)>(46, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'contextmenu_delete'
        QtMocHelpers::SlotData<void(bool)>(47, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'contextmenu_newfile'
        QtMocHelpers::SlotData<void(bool)>(48, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'contextmenu_newdir'
        QtMocHelpers::SlotData<void(bool)>(49, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'contextmenu_setcurrentdir'
        QtMocHelpers::SlotData<void(bool)>(50, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'contextmenu_add_to_path'
        QtMocHelpers::SlotData<void(bool, bool, bool)>(51, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 }, { QMetaType::Bool, 20 }, { QMetaType::Bool, 21 },
        }}),
        // Slot 'contextmenu_add_to_path'
        QtMocHelpers::SlotData<void(bool, bool)>(51, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Bool, 2 }, { QMetaType::Bool, 20 },
        }}),
        // Slot 'contextmenu_add_to_path'
        QtMocHelpers::SlotData<void(bool)>(51, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'contextmenu_add_to_path_subdirs'
        QtMocHelpers::SlotData<void(bool)>(52, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'contextmenu_rm_from_path'
        QtMocHelpers::SlotData<void(bool)>(53, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'contextmenu_rm_from_path_subdirs'
        QtMocHelpers::SlotData<void(bool)>(54, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'contextmenu_findfiles'
        QtMocHelpers::SlotData<void(bool)>(55, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'popdownmenu_newfile'
        QtMocHelpers::SlotData<void(bool)>(56, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'popdownmenu_newdir'
        QtMocHelpers::SlotData<void(bool)>(57, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'popdownmenu_search_dir'
        QtMocHelpers::SlotData<void(bool)>(58, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'popdownmenu_findfiles'
        QtMocHelpers::SlotData<void(bool)>(59, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'popdownmenu_home'
        QtMocHelpers::SlotData<void(bool)>(60, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'copyClipboard'
        QtMocHelpers::SlotData<void()>(61, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'pasteClipboard'
        QtMocHelpers::SlotData<void()>(62, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'selectAll'
        QtMocHelpers::SlotData<void()>(63, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<file_system_browser, qt_meta_tag_ZN6octave19file_system_browserE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject octave::file_system_browser::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6octave19file_system_browserE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6octave19file_system_browserE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6octave19file_system_browserE_t>.metaTypes,
    nullptr
} };

void octave::file_system_browser::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<file_system_browser *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->open_file((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->displayed_directory_changed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->load_file_signal((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->open_any_signal((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->run_file_signal((*reinterpret_cast<std::add_pointer_t<QFileInfo>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 5: _t->find_files_signal((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->file_remove_signal((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 7: _t->file_renamed_signal((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 8: _t->modify_path_signal((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 9: _t->item_double_clicked((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 10: _t->change_directory_up(); break;
        case 11: _t->do_sync_octave_directory(); break;
        case 12: _t->do_sync_browser_directory(); break;
        case 13: _t->set_current_directory((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 14: _t->accept_directory_line_edit(); break;
        case 15: _t->update_octave_directory((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 16: _t->notice_settings(); break;
        case 17: _t->save_settings(); break;
        case 18: _t->restore_header_state(); break;
        case 19: _t->headercontextmenu_requested((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 20: _t->toggle_header((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 21: _t->contextmenu_requested((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 22: _t->contextmenu_open((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 23: _t->contextmenu_open_in_editor((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 24: _t->contextmenu_open_in_app((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 25: _t->contextmenu_copy_selection((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 26: _t->contextmenu_run((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 27: _t->contextmenu_load((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 28: _t->contextmenu_rename((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 29: _t->contextmenu_delete((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 30: _t->contextmenu_newfile((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 31: _t->contextmenu_newdir((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 32: _t->contextmenu_setcurrentdir((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 33: _t->contextmenu_add_to_path((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 34: _t->contextmenu_add_to_path((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 35: _t->contextmenu_add_to_path((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 36: _t->contextmenu_add_to_path_subdirs((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 37: _t->contextmenu_rm_from_path((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 38: _t->contextmenu_rm_from_path_subdirs((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 39: _t->contextmenu_findfiles((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 40: _t->popdownmenu_newfile((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 41: _t->popdownmenu_newdir((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 42: _t->popdownmenu_search_dir((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 43: _t->popdownmenu_findfiles((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 44: _t->popdownmenu_home((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 45: _t->copyClipboard(); break;
        case 46: _t->pasteClipboard(); break;
        case 47: _t->selectAll(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (file_system_browser::*)(const QString & )>(_a, &file_system_browser::open_file, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (file_system_browser::*)(const QString & )>(_a, &file_system_browser::displayed_directory_changed, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (file_system_browser::*)(const QString & )>(_a, &file_system_browser::load_file_signal, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (file_system_browser::*)(const QString & )>(_a, &file_system_browser::open_any_signal, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (file_system_browser::*)(const QFileInfo & , int )>(_a, &file_system_browser::run_file_signal, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (file_system_browser::*)(const QString & )>(_a, &file_system_browser::find_files_signal, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (file_system_browser::*)(const QString & , const QString & )>(_a, &file_system_browser::file_remove_signal, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (file_system_browser::*)(bool )>(_a, &file_system_browser::file_renamed_signal, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (file_system_browser::*)(const QStringList & , bool , bool )>(_a, &file_system_browser::modify_path_signal, 8))
            return;
    }
}

const QMetaObject *octave::file_system_browser::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *octave::file_system_browser::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6octave19file_system_browserE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int octave::file_system_browser::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 48)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 48;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 48)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 48;
    }
    return _id;
}

// SIGNAL 0
void octave::file_system_browser::open_file(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void octave::file_system_browser::displayed_directory_changed(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void octave::file_system_browser::load_file_signal(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void octave::file_system_browser::open_any_signal(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void octave::file_system_browser::run_file_signal(const QFileInfo & _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}

// SIGNAL 5
void octave::file_system_browser::find_files_signal(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void octave::file_system_browser::file_remove_signal(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2);
}

// SIGNAL 7
void octave::file_system_browser::file_renamed_signal(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void octave::file_system_browser::modify_path_signal(const QStringList & _t1, bool _t2, bool _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1, _t2, _t3);
}
namespace {
struct qt_meta_tag_ZN6octave20editor_files_browserE_t {};
} // unnamed namespace

template <> constexpr inline auto octave::editor_files_browser::qt_create_metaobjectdata<qt_meta_tag_ZN6octave20editor_files_browserE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "octave::editor_files_browser",
        "focus_editor_file_signal",
        "",
        "file",
        "close_editor_file_signal",
        "files_to_remove",
        "run_file_signal",
        "QFileInfo",
        "info",
        "ops",
        "displayed_directory_changed",
        "dir",
        "rename_editor_file",
        "old_file",
        "new_file",
        "remove_editor_file",
        "fname",
        "contextmenu_requested",
        "QPoint",
        "pos",
        "clicked",
        "QModelIndex",
        "index",
        "notice_settings",
        "save_settings",
        "ctx_menu_close",
        "ctx_menu_close_all",
        "ctx_menu_run",
        "ctx_menu_setcurrentdir"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'focus_editor_file_signal'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'close_editor_file_signal'
        QtMocHelpers::SignalData<void(const QStringList &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 5 },
        }}),
        // Signal 'run_file_signal'
        QtMocHelpers::SignalData<void(const QFileInfo &, int)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 }, { QMetaType::Int, 9 },
        }}),
        // Signal 'displayed_directory_changed'
        QtMocHelpers::SignalData<void(const QString &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 11 },
        }}),
        // Slot 'rename_editor_file'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 13 }, { QMetaType::QString, 14 },
        }}),
        // Slot 'rename_editor_file'
        QtMocHelpers::SlotData<void(const QString &)>(12, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 13 },
        }}),
        // Slot 'remove_editor_file'
        QtMocHelpers::SlotData<void(const QString &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 16 },
        }}),
        // Slot 'contextmenu_requested'
        QtMocHelpers::SlotData<void(const QPoint &)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 18, 19 },
        }}),
        // Slot 'clicked'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 21, 22 },
        }}),
        // Slot 'notice_settings'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'save_settings'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'ctx_menu_close'
        QtMocHelpers::SlotData<void(bool)>(25, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'ctx_menu_close_all'
        QtMocHelpers::SlotData<void(bool)>(26, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'ctx_menu_run'
        QtMocHelpers::SlotData<void(bool)>(27, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'ctx_menu_setcurrentdir'
        QtMocHelpers::SlotData<void(bool)>(28, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<editor_files_browser, qt_meta_tag_ZN6octave20editor_files_browserE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject octave::editor_files_browser::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6octave20editor_files_browserE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6octave20editor_files_browserE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6octave20editor_files_browserE_t>.metaTypes,
    nullptr
} };

void octave::editor_files_browser::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<editor_files_browser *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->focus_editor_file_signal((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->close_editor_file_signal((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 2: _t->run_file_signal((*reinterpret_cast<std::add_pointer_t<QFileInfo>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 3: _t->displayed_directory_changed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->rename_editor_file((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 5: _t->rename_editor_file((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->remove_editor_file((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->contextmenu_requested((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 8: _t->clicked((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 9: _t->notice_settings(); break;
        case 10: _t->save_settings(); break;
        case 11: _t->ctx_menu_close((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 12: _t->ctx_menu_close_all((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 13: _t->ctx_menu_run((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 14: _t->ctx_menu_setcurrentdir((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (editor_files_browser::*)(const QString & )>(_a, &editor_files_browser::focus_editor_file_signal, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (editor_files_browser::*)(const QStringList & )>(_a, &editor_files_browser::close_editor_file_signal, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (editor_files_browser::*)(const QFileInfo & , int )>(_a, &editor_files_browser::run_file_signal, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (editor_files_browser::*)(const QString & )>(_a, &editor_files_browser::displayed_directory_changed, 3))
            return;
    }
}

const QMetaObject *octave::editor_files_browser::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *octave::editor_files_browser::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6octave20editor_files_browserE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int octave::editor_files_browser::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 15)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 15;
    }
    return _id;
}

// SIGNAL 0
void octave::editor_files_browser::focus_editor_file_signal(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void octave::editor_files_browser::close_editor_file_signal(const QStringList & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void octave::editor_files_browser::run_file_signal(const QFileInfo & _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void octave::editor_files_browser::displayed_directory_changed(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN6octave17files_dock_widgetE_t {};
} // unnamed namespace

template <> constexpr inline auto octave::files_dock_widget::qt_create_metaobjectdata<qt_meta_tag_ZN6octave17files_dock_widgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "octave::files_dock_widget",
        "notice_settings",
        "",
        "save_settings"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'notice_settings'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'save_settings'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<files_dock_widget, qt_meta_tag_ZN6octave17files_dock_widgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject octave::files_dock_widget::staticMetaObject = { {
    QMetaObject::SuperData::link<octave_dock_widget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6octave17files_dock_widgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6octave17files_dock_widgetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6octave17files_dock_widgetE_t>.metaTypes,
    nullptr
} };

void octave::files_dock_widget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<files_dock_widget *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->notice_settings(); break;
        case 1: _t->save_settings(); break;
        default: ;
        }
    }
    (void)_a;
}

const QMetaObject *octave::files_dock_widget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *octave::files_dock_widget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6octave17files_dock_widgetE_t>.strings))
        return static_cast<void*>(this);
    return octave_dock_widget::qt_metacast(_clname);
}

int octave::files_dock_widget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = octave_dock_widget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    return _id;
}
QT_WARNING_POP
